==> members-facade-1.0.2-20190722.123920-203-sources.jar: com/bizvane/members/facade/service/card/response/FocusOnResponseModel.java <==
package com.bizvane.members.facade.service.card.response;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/10.
 */
@Data
public class FocusOnResponseModel {

    @ApiModelProperty(name = "appId", value = "appId")
    private String appId;

    @ApiModelProperty(name = "openId", value = "openId")
    private String openId;

    @ApiModelProperty(name = "unionId", value = "unionId")
    private String unionId;

    @ApiModelProperty(name = "wxNick", value = "微信昵称")
    private String wxNick;

    @ApiModelProperty(name = "headPortraits", value = "微信头像")
    private String headPortraits;

    @ApiModelProperty(name = "cardNo",value = "卡号")
    private String cardNo;

    @ApiModelProperty(name = "levelName", value = "等级名称")
    private String levelName;

    @ApiModelProperty(name = "countIntegral", value = "累计可用积分")
    private Integer countIntegral;

    @ApiModelProperty(name = "cardStatus", value = "绑卡状态")
    private Integer cardStatus;

    @ApiModelProperty(name = "miniProgram", value = "是否为小程序：1微信2小程序")
    private Integer miniProgram;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "code", value = "响应code")
    private Integer code;

    @ApiModelProperty(name = "message", value = "响应信息")
    private String message;

    @ApiModelProperty(value = "品牌id", name = "brandId")
    private Long brandId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId")
    private Long sysCompanyId;

}

==> members-facade-2.1.1-20201120.042240-11-sources.jar: com/bizvane/members/facade/service/card/response/FocusOnResponseModel.java <==
package com.bizvane.members.facade.service.card.response;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/10.
 */
@Data
public class FocusOnResponseModel {

    @ApiModelProperty(name = "appId", value = "appId")
    private String appId;

    @ApiModelProperty(name = "openId", value = "openId")
    private String openId;

    @ApiModelProperty(name = "unionId", value = "unionId")
    private String unionId;

    @ApiModelProperty(name = "wxNick", value = "微信昵称")
    private String wxNick;

    @ApiModelProperty(name = "headPortraits", value = "微信头像")
    private String headPortraits;

    @ApiModelProperty(name = "cardNo",value = "卡号")
    private String cardNo;

    @ApiModelProperty(name = "levelName", value = "等级名称")
    private String levelName;

    @ApiModelProperty(name = "countIntegral", value = "累计可用积分")
    private Integer countIntegral;

    @ApiModelProperty(name = "cardStatus", value = "绑卡状态")
    private Integer cardStatus;

    @ApiModelProperty(name = "miniProgram", value = "是否为小程序：1微信2小程序")
    private Integer miniProgram;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "code", value = "响应code")
    private Integer code;

    @ApiModelProperty(name = "message", value = "响应信息")
    private String message;

    @ApiModelProperty(value = "品牌id", name = "brandId")
    private Long brandId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId")
    private Long sysCompanyId;

    @ApiModelProperty(name = "province", value = "省")
    private String province;

    @ApiModelProperty(name = "city", value = "市")
    private String city;

    @ApiModelProperty(name = "county", value = "区县")
    private String county;

    @ApiModelProperty(name = "gender", value = "性别:1男，0女")
    private String gender;
}
